BaseViewModel class

Implementers

Constructors

BaseViewModel()

Properties

errorMessage → Stream<String>
no setter
hashCode → int
The hash code for this object.
no setterinherited
isLoading → bool
no setter
loading → Stream<bool>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearError() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postError(String error) → void
setLoading({bool? value}) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited