GrantRemoteDataSource class abstract

Implementers

Constructors

GrantRemoteDataSource()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addGrant({required Map<String, dynamic> body}) → Future<Either<NetworkException, GrantApiDto>>
deleteGrant({required String id}) → Future<Either<NetworkException, NoContentApiDto>>
getGrantsFromUserById({required String id, dynamic include = 'role'}) → Future<Either<NetworkException, List<GrantApiDto>>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited