ImageApi class

Inheritance

Constructors

ImageApi({required PreferencesSettings settings})

Properties

baseUrl → Future<String>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → PreferencesSettings
finalinherited

Methods

cleanEntity(Map<String, dynamic> params) → Map<String, dynamic>
inherited
delete(String endpoint, {bool includeToken = true}) → Future<Response>
inherited
get(String endpoint, {bool includeToken = true}) → Future<Response>
inherited
getHeaders({bool includeToken = true}) → Map<String, String>
inherited
getImage(Map<String, dynamic> params) → Future<BytesResponse>
getUrl({String? endUrl}) → Future<Uri>
inherited
handleFilters(String url, Map<String, dynamic> filters) → String
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseImageUrl(String imageId, {String quality = 'max'}) → Future<String>
parseUrl(String url) → Uri
inherited
post(String endpoint, {bool includeToken = true, Map<String, dynamic>? body, Map<String, String>? headers}) → Future<Response>
inherited
put(String endpoint, {bool includeToken = true, Map<String, dynamic>? body}) → Future<Response>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

ENDPOINT → const String