BadRequest class

Inheritance
Available extensions

Constructors

BadRequest({required dynamic message, required dynamic isRetryAble, dynamic code, dynamic cause})

Properties

cause ↔ Exception?
getter/setter pairinherited
code ↔ int?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
isRetryAble ↔ bool
getter/setter pairinherited
message ↔ String
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

handleNetworkException() → NetworkException

Available on NetworkException, provided by the NetworkErrorHandling extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited